@@ -1,6 +1,8 @@
 """ recording warnings during test function execution. """
 
 import inspect
+
+import _pytest._code
 import py
 import sys
 import warnings
@@ -28,14 +30,27 @@ def pytest_namespace():
             'warns': warns}
 
 
-def deprecated_call(func, *args, **kwargs):
+def deprecated_call(func=None, *args, **kwargs):
     """ assert that calling ``func(*args, **kwargs)`` triggers a
     ``DeprecationWarning`` or ``PendingDeprecationWarning``.
 
+    This function can be used as a context manager::
+
+        >>> import warnings
+        >>> def api_call_v2():
+        ...     warnings.warn('use v3 of this api', DeprecationWarning)
+        ...     return 200
+
+        >>> with deprecated_call():
+        ...    assert api_call_v2() == 200
+
     Note: we cannot use WarningsRecorder here because it is still subject
     to the mechanism that prevents warnings of the same type from being
     triggered twice for the same module. See #1190.
     """
+    if not func:
+        return WarningsChecker(expected_warning=DeprecationWarning)
+
     categories = []
 
     def warn_explicit(message, category, *args, **kwargs):
@@ -92,7 +107,7 @@ def warns(expected_warning, *args, **kwargs):
         loc.update(kwargs)
 
         with wcheck:
-            code = py.code.Source(code).compile()
+            code = _pytest._code.Source(code).compile()
             py.builtin.exec_(code, frame.f_globals, loc)
     else:
         func = args[0]
@@ -171,8 +186,8 @@ class WarningsRecorder(object):
         self._module.showwarning = showwarning
 
         # allow the same warning to be raised more than once
-        self._module.simplefilter('always', append=True)
 
+        self._module.simplefilter('always')
         return self
 
     def __exit__(self, *exc_info):
@@ -208,4 +223,7 @@ class WarningsChecker(WarningsRecorder):
             if self.expected_warning is not None:
                 if not any(r.category in self.expected_warning for r in self):
                     __tracebackhide__ = True
-                    pytest.fail("DID NOT WARN")
+                    pytest.fail("DID NOT WARN. No warnings of type {0} was emitted. "
+                                "The list of emitted warnings is: {1}.".format(
+                                    self.expected_warning,
+                                    [each.message for each in self]))
