@@ -5,7 +5,7 @@ import sys
 import traceback
 
 import pytest
-# for transfering markers
+# for transferring markers
 import _pytest._code
 from _pytest.python import transfer_markers
 from _pytest.skipping import MarkEvaluator
@@ -65,7 +65,6 @@ class UnitTestCase(pytest.Class):
                     yield TestCaseFunction('runTest', parent=self)
 
 
-
 class TestCaseFunction(pytest.Function):
     _excinfo = None
 
@@ -94,6 +93,9 @@ class TestCaseFunction(pytest.Function):
     def teardown(self):
         if hasattr(self._testcase, 'teardown_method'):
             self._testcase.teardown_method(self._obj)
+        # Allow garbage collection on TestCase instance attributes.
+        self._testcase = None
+        self._obj = None
 
     def startTest(self, testcase):
         pass
@@ -149,14 +151,33 @@ class TestCaseFunction(pytest.Function):
     def stopTest(self, testcase):
         pass
 
+    def _handle_skip(self):
+        # implements the skipping machinery (see #2137)
+        # analog to pythons Lib/unittest/case.py:run
+        testMethod = getattr(self._testcase, self._testcase._testMethodName)
+        if (getattr(self._testcase.__class__, "__unittest_skip__", False) or
+            getattr(testMethod, "__unittest_skip__", False)):
+            # If the class or method was skipped.
+            skip_why = (getattr(self._testcase.__class__, '__unittest_skip_why__', '') or
+                        getattr(testMethod, '__unittest_skip_why__', ''))
+            try:  # PY3, unittest2 on PY2
+                self._testcase._addSkip(self, self._testcase, skip_why)
+            except TypeError:  # PY2
+                if sys.version_info[0] != 2:
+                    raise
+                self._testcase._addSkip(self, skip_why)
+            return True
+        return False
+
     def runtest(self):
         if self.config.pluginmanager.get_plugin("pdbinvoke") is None:
             self._testcase(result=self)
         else:
             # disables tearDown and cleanups for post mortem debugging (see #1890)
+            if self._handle_skip():
+                return
             self._testcase.debug()
 
-
     def _prunetraceback(self, excinfo):
         pytest.Function._prunetraceback(self, excinfo)
         traceback = excinfo.traceback.filter(
@@ -183,6 +204,7 @@ def pytest_runtest_protocol(item):
         ut = sys.modules['twisted.python.failure']
         Failure__init__ = ut.Failure.__init__
         check_testcase_implements_trial_reporter()
+
         def excstore(self, exc_value=None, exc_type=None, exc_tb=None,
             captureVars=None):
             if exc_value is None:
@@ -196,6 +218,7 @@ def pytest_runtest_protocol(item):
                     captureVars=captureVars)
             except TypeError:
                 Failure__init__(self, exc_value, exc_type, exc_tb)
+
         ut.Failure.__init__ = excstore
         yield
         ut.Failure.__init__ = Failure__init__
